@@ -1,8 +1,7 @@
 use structopt::StructOpt;
-use tokio_stream::StreamExt;
 use tracing::Level;
 use tracing_subscriber::util::SubscriberInitExt;
-use ws_tool::{codec::default_string_check_fn, ClientBuilder};
+use ws_tool::{codec::AsyncWsStringCodec, ClientBuilder};
 
 /// websocket client connect to binance futures websocket
 #[derive(StructOpt)]
@@ -18,7 +17,7 @@ struct Args {
 #[tokio::main]
 async fn main() -> Result<(), ()> {
     tracing_subscriber::fmt::fmt()
-        .with_max_level(Level::DEBUG)
+        .with_max_level(Level::INFO)
         .finish()
         .try_init()
         .expect("failed to init log");
@@ -32,12 +31,12 @@ async fn main() -> Result<(), ()> {
         builder = builder.proxy(&proxy)
     }
     let mut client = builder
-        .connect_with_check(default_string_check_fn)
+        .async_connect(AsyncWsStringCodec::check_fn)
         .await
         .unwrap();
 
-    while let Some(Ok((_, msg))) = client.next().await {
-        println!("{}", msg.trim());
+    while let Ok(msg) = client.receive().await {
+        println!("{}", msg.data.trim());
     }
     Ok(())
 }
