@@ -1,11 +1,9 @@
 use std::{io::Write, path::PathBuf};
 
-use futures::SinkExt;
 use structopt::StructOpt;
-use tokio_stream::StreamExt;
 use tracing::Level;
 use tracing_subscriber::util::SubscriberInitExt;
-use ws_tool::{codec::default_string_check_fn, ClientBuilder};
+use ws_tool::{codec::AsyncWsStringCodec, ClientBuilder};
 
 /// websocket client demo with raw frame
 #[derive(StructOpt)]
@@ -36,7 +34,7 @@ async fn main() -> Result<(), ()> {
         builder = builder.proxy(&proxy)
     }
     let mut client = builder
-        .connect_with_check(default_string_check_fn)
+        .async_connect(AsyncWsStringCodec::check_fn)
         .await
         .unwrap();
 
@@ -49,14 +47,18 @@ async fn main() -> Result<(), ()> {
             break;
         }
         client.send(input.clone()).await.unwrap();
-        if let Some(Ok((_, msg))) = client.next().await {
-            println!("[RECV] > {}", msg.trim());
-            if &msg == "quit" {
-                break;
+        match client.receive().await {
+            Ok(item) => {
+                println!("[RECV] > {}", item.data.trim());
+                if item.data == "quit" {
+                    break;
+                }
+                input.clear()
             }
-            input.clear()
-        } else {
-            break;
+            Err(e) => {
+                dbg!(e);
+                break;
+            },
         }
     }
     Ok(())
